@@ -37,8 +37,8 @@ static struct io_u *fio_skeleton_event(struct thread_data *td, int event)
  * which may then be retrieved by calling the ->event() hook with the event
  * numbers. Required.
  */
-static int fio_skeleton_getevents(struct thread_data *td, int min, int max,
-				  struct timespec *t)
+static int fio_skeleton_getevents(struct thread_data *td, unsigned int min,
+				  unsigned int max, const struct timespec *t)
 {
 	return 0;
 }
@@ -59,7 +59,7 @@ static int fio_skeleton_cancel(struct thread_data *td, struct io_u *io_u)
  *
  * The io engine must transfer in the direction noted by io_u->ddir
  * to the buffer pointed to by io_u->xfer_buf for as many bytes as
- * io_u->xfer_buflen. Residual data count may be set in io_u->residual
+ * io_u->xfer_buflen. Residual data count may be set in io_u->resid
  * for a short read/write.
  */
 static int fio_skeleton_queue(struct thread_data *td, struct io_u *io_u)
@@ -99,7 +99,7 @@ static int fio_skeleton_init(struct thread_data *td)
 }
 
 /*
- * This is paired with the ->init() funtion and is called when a thread is
+ * This is paired with the ->init() function and is called when a thread is
  * done doing io. Should tear down anything setup by the ->init() function.
  * Not required.
  */
@@ -109,11 +109,11 @@ static void fio_skeleton_cleanup(struct thread_data *td)
 
 /*
  * Hook for opening the given file. Unless the engine has special
- * needs, it usually just provides generic_file_open() as the handler.
+ * needs, it usually just provides generic_open_file() as the handler.
  */
 static int fio_skeleton_open(struct thread_data *td, struct fio_file *f)
 {
-	return generic_file_open(td, f);
+	return generic_open_file(td, f);
 }
 
 /*
@@ -121,12 +121,12 @@ static int fio_skeleton_open(struct thread_data *td, struct fio_file *f)
  */
 static int fio_skeleton_close(struct thread_data *td, struct fio_file *f)
 {
-	generic_file_close(td, f);
+	return generic_close_file(td, f);
 }
 
 /*
  * Note that the structure is exported, so that fio can get it via
- * dlsym(..., "ioengine");
+ * dlsym(..., "ioengine"); for (and only for) external engines.
  */
 struct ioengine_ops ioengine = {
 	.name		= "engine_name",
